import grpc
import control_server_pb2_grpc
import control_server_pb2

import os

class PyScaleboxApi():
    def __init__(self):
        self.body = ""
        self.a = 0

    def send_message(self,body):
        channel = grpc.insecure_channel(os.getenv('CSST_PIPELINE_GRPC_SERVER'))

        stub = control_server_pb2_grpc.BoxServiceStub(channel)
        test = control_server_pb2.JobKey()
        test.job1_name = str(os.getenv('CSST_ADML2_NAME'))
        test.job0_id = int(os.getenv('CSST_ADML2_JOB_ID'))
        print("test.job1_name = "+os.getenv('CSST_ADML2_NAME'))

        test.key_text = body
        self.body = body
        
        reflag = stub.SendToNextJob(test)
        print(reflag.value)
        return reflag.value
    def func(self,a):
        b = a + 1
        self.a = a
        return b


    
# import grpc
# import control_server_pb2_grpc
# import control_server_pb2
# import os

# body="brickid,name1,name2,name3"
# channel = grpc.insecure_channel(os.getenv('CSST_PIPELINE_GRPC_SERVER'))

# stub = control_server_pb2_grpc.BoxServiceStub(channel)
# test = control_server_pb2.JobKey()
# test.job1_name = str(os.getenv('CSST_ADML2_NAME'))
# test.job0_id = int(os.getenv('CSST_ADML2_JOB_ID'))

# test.key_text = body
# reflag = stub.SendToNextJob(test)
# print(reflag.value)
        


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: control-server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63ontrol-server.proto\x12\x08scalebox\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\">\n\x06JobKey\x12\x11\n\tjob1_name\x18\x01 \x01(\t\x12\x10\n\x08key_text\x18\x02 \x01(\t\x12\x0f\n\x07job0_id\x18\x03 \x01(\x05\"K\n\x07JobKeys\x12\x15\n\rnext_job_name\x18\x01 \x01(\t\x12\x11\n\tkey_texts\x18\x02 \x03(\t\x12\x16\n\x0e\x63urrent_job_id\x18\x03 \x01(\x05\"#\n\x08TaskItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03key\x18\x02 \x01(\t\"9\n\x07\x43ommand\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x14\n\x0c\x63ommand_text\x18\x03 \x01(\t\"1\n\x0b\x43ommandList\x12\"\n\x07\x63ommand\x18\x01 \x03(\x0b\x32\x11.scalebox.Command\"\x88\x03\n\x0fTaskExecMessage\x12\x0c\n\x04slot\x18\x01 \x01(\x05\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07task_id\x18\x03 \x01(\x03\x12\x13\n\x0binput_bytes\x18\x04 \x01(\x03\x12\x14\n\x0coutput_bytes\x18\x05 \x01(\x03\x12&\n\x02t0\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02t1\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02t2\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02t3\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02t4\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08time_arr\x18\x0b \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07sys_out\x18\x0c \x01(\t\x12\x0f\n\x07\x61pp_out\x18\r \x01(\t2\x8f\x08\n\nBoxService\x12\x42\n\x04\x45\x63ho\x12\x1c.google.protobuf.StringValue\x1a\x1c.google.protobuf.StringValue\x12>\n\x0bGetNextTask\x12\x1b.google.protobuf.Int32Value\x1a\x12.scalebox.TaskItem\x12J\n\x0eSetTaskStarted\x12\x1b.google.protobuf.Int64Value\x1a\x1b.google.protobuf.Int32Value\x12I\n\x0fSetTaskFinished\x12\x19.scalebox.TaskExecMessage\x1a\x1b.google.protobuf.Int32Value\x12M\n\x11SetSlotTerminated\x12\x1b.google.protobuf.Int32Value\x1a\x1b.google.protobuf.Int32Value\x12\x44\n\x13GetRunnableSlotList\x12\x16.google.protobuf.Empty\x1a\x15.scalebox.CommandList\x12N\n\x12SetSlotInitialized\x12\x1b.google.protobuf.Int32Value\x1a\x1b.google.protobuf.Int32Value\x12\x46\n\x15GetTerminableSlotList\x12\x16.google.protobuf.Empty\x1a\x15.scalebox.CommandList\x12\x46\n\x15GetRunnableWorkerList\x12\x16.google.protobuf.Empty\x1a\x15.scalebox.CommandList\x12P\n\x14SetWorkerInitialized\x12\x1b.google.protobuf.Int32Value\x1a\x1b.google.protobuf.Int32Value\x12H\n\x17GetTerminableWorkerList\x12\x16.google.protobuf.Empty\x1a\x15.scalebox.CommandList\x12O\n\x13SetWorkerTerminated\x12\x1b.google.protobuf.Int32Value\x1a\x1b.google.protobuf.Int32Value\x12>\n\rSendToNextJob\x12\x10.scalebox.JobKey\x1a\x1b.google.protobuf.Int32Value\x12\x44\n\x12SendMessagesToNext\x12\x11.scalebox.JobKeys\x1a\x1b.google.protobuf.Int32ValueB\x15\n\x11\x64\x65v.scalebox.gprcP\x01\x62\x06proto3')



_JOBKEY = DESCRIPTOR.message_types_by_name['JobKey']
_JOBKEYS = DESCRIPTOR.message_types_by_name['JobKeys']
_TASKITEM = DESCRIPTOR.message_types_by_name['TaskItem']
_COMMAND = DESCRIPTOR.message_types_by_name['Command']
_COMMANDLIST = DESCRIPTOR.message_types_by_name['CommandList']
_TASKEXECMESSAGE = DESCRIPTOR.message_types_by_name['TaskExecMessage']
JobKey = _reflection.GeneratedProtocolMessageType('JobKey', (_message.Message,), {
  'DESCRIPTOR' : _JOBKEY,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.JobKey)
  })
_sym_db.RegisterMessage(JobKey)

JobKeys = _reflection.GeneratedProtocolMessageType('JobKeys', (_message.Message,), {
  'DESCRIPTOR' : _JOBKEYS,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.JobKeys)
  })
_sym_db.RegisterMessage(JobKeys)

TaskItem = _reflection.GeneratedProtocolMessageType('TaskItem', (_message.Message,), {
  'DESCRIPTOR' : _TASKITEM,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.TaskItem)
  })
_sym_db.RegisterMessage(TaskItem)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), {
  'DESCRIPTOR' : _COMMAND,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.Command)
  })
_sym_db.RegisterMessage(Command)

CommandList = _reflection.GeneratedProtocolMessageType('CommandList', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDLIST,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.CommandList)
  })
_sym_db.RegisterMessage(CommandList)

TaskExecMessage = _reflection.GeneratedProtocolMessageType('TaskExecMessage', (_message.Message,), {
  'DESCRIPTOR' : _TASKEXECMESSAGE,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.TaskExecMessage)
  })
_sym_db.RegisterMessage(TaskExecMessage)

_BOXSERVICE = DESCRIPTOR.services_by_name['BoxService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021dev.scalebox.gprcP\001'
  _JOBKEY._serialized_start=128
  _JOBKEY._serialized_end=190
  _JOBKEYS._serialized_start=192
  _JOBKEYS._serialized_end=267
  _TASKITEM._serialized_start=269
  _TASKITEM._serialized_end=304
  _COMMAND._serialized_start=306
  _COMMAND._serialized_end=363
  _COMMANDLIST._serialized_start=365
  _COMMANDLIST._serialized_end=414
  _TASKEXECMESSAGE._serialized_start=417
  _TASKEXECMESSAGE._serialized_end=809
  _BOXSERVICE._serialized_start=812
  _BOXSERVICE._serialized_end=1851
# @@protoc_insertion_point(module_scope)



from setuptools import setup,find_packages
setup(name='pyscalebox',
      version='0.0.3',
      description='level 2 pipeline api:send_message(body)',
      author='zhangxiaoli',
      author_email='zhangxiaoli@cnic.cn',
      requires=['os','grpc'], # 定义依赖哪些模块
      py_modules=['pyscalebox','control_server_pb2','control_server_pb2_grpc'],  # 系统自动从当前目录开始找包
      # packages=find_packages(),
      license="apache 3.0"
      )


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import control_server_pb2 as control__server__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


class BoxServiceStub(object):
    """service ControlService {
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Echo = channel.unary_unary(
                '/scalebox.BoxService/Echo',
                request_serializer=google_dot_protobuf_dot_wrappers__pb2.StringValue.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.StringValue.FromString,
                )
        self.GetNextTask = channel.unary_unary(
                '/scalebox.BoxService/GetNextTask',
                request_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
                response_deserializer=control__server__pb2.TaskItem.FromString,
                )
        self.SetTaskStarted = channel.unary_unary(
                '/scalebox.BoxService/SetTaskStarted',
                request_serializer=google_dot_protobuf_dot_wrappers__pb2.Int64Value.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                )
        self.SetTaskFinished = channel.unary_unary(
                '/scalebox.BoxService/SetTaskFinished',
                request_serializer=control__server__pb2.TaskExecMessage.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                )
        self.SetSlotTerminated = channel.unary_unary(
                '/scalebox.BoxService/SetSlotTerminated',
                request_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                )
        self.GetRunnableSlotList = channel.unary_unary(
                '/scalebox.BoxService/GetRunnableSlotList',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=control__server__pb2.CommandList.FromString,
                )
        self.SetSlotInitialized = channel.unary_unary(
                '/scalebox.BoxService/SetSlotInitialized',
                request_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                )
        self.GetTerminableSlotList = channel.unary_unary(
                '/scalebox.BoxService/GetTerminableSlotList',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=control__server__pb2.CommandList.FromString,
                )
        self.GetRunnableWorkerList = channel.unary_unary(
                '/scalebox.BoxService/GetRunnableWorkerList',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=control__server__pb2.CommandList.FromString,
                )
        self.SetWorkerInitialized = channel.unary_unary(
                '/scalebox.BoxService/SetWorkerInitialized',
                request_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                )
        self.GetTerminableWorkerList = channel.unary_unary(
                '/scalebox.BoxService/GetTerminableWorkerList',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=control__server__pb2.CommandList.FromString,
                )
        self.SetWorkerTerminated = channel.unary_unary(
                '/scalebox.BoxService/SetWorkerTerminated',
                request_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                )
        self.SendToNextJob = channel.unary_unary(
                '/scalebox.BoxService/SendToNextJob',
                request_serializer=control__server__pb2.JobKey.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                )
        self.SendMessagesToNext = channel.unary_unary(
                '/scalebox.BoxService/SendMessagesToNext',
                request_serializer=control__server__pb2.JobKeys.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                )


class BoxServiceServicer(object):
    """service ControlService {
    """

    def Echo(self, request, context):
        """//////////////////////////////////////////////////////////////////
        agent client
        //////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNextTask(self, request, context):
        """input : slot id('ON')
        return : job-key of the task, id==0(NULL)
        task id : 'READY/-1' -> 'QUEUED/-2'
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTaskStarted(self, request, context):
        """input : task id('QUEUED/-2')
        return : ret_code : 0(OK), -1(task NOT FOUND), -2(WRONG STATUS)
        task_status_code:'QUEUED'/-2 -> 'RUNNING'/-3
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTaskFinished(self, request, context):
        """input : TaskExecMessage
        return : ret_code : 0(OK), -1(task NOT FOUND), -2(task WRONG STATUS)
        task_status_code:'RUNNING'/-3 -> 'OK'/0, ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSlotTerminated(self, request, context):
        """if on-demand-job, slot exit automatically, called in agent side
        if long-run-job, slot terminated by actuator
        input : slot id
        return : ret_code : 0(OK), -1(slot NOT FOUND), -2(slot WRONG STATUS)
        slot : 'ON' -> 'OFF'
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRunnableSlotList(self, request, context):
        """//////////////////////////////////////////////////////////////////
        actuator client
        //////////////////////////////////////////////////////////////////
        input: token_string ?
        job:'RUNNING' && slot:'READY'
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSlotInitialized(self, request, context):
        """input : slot id
        return : ret_code : 0(OK), -1(slot NOT FOUND), -2(slot WRONG STATUS)
        slot: 'READY' -> 'ON'
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTerminableSlotList(self, request, context):
        """job:'PAUSED'/'ARCHIVED' && slot:'ON'
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRunnableWorkerList(self, request, context):
        """job:'RUNNING' && worker:'PAUSED'
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetWorkerInitialized(self, request, context):
        """input : worker id
        return : ret_code : 0(OK), -1(worker NOT FOUND), -2(worker WRONG STATUS)
        worker: 'PAUSED' -> 'RUNNING'
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTerminableWorkerList(self, request, context):
        """job:'PAUSED' && worker:'RUNNING'
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetWorkerTerminated(self, request, context):
        """input : worker id, return ret_code;
        return : ret_code : 0(OK), -1(worker NOT FOUND), -2(worker WRONG STATUS)
        worker : 'RUNNING' -> 'PAUSED'
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendToNextJob(self, request, context):
        """//////////////////////////////////////////////////////////////////
        app client , called by user app.
        //////////////////////////////////////////////////////////////////

        send task-key to next job in current app
        return : ret_code : 0(OK), -1(job NOT FOUND)
        task_status_code : 'INITIAL'/-9
        rpc SendJobMessage(JobMessage) returns (google.protobuf.Int32Value);
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendMessagesToNext(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BoxServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Echo': grpc.unary_unary_rpc_method_handler(
                    servicer.Echo,
                    request_deserializer=google_dot_protobuf_dot_wrappers__pb2.StringValue.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.StringValue.SerializeToString,
            ),
            'GetNextTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNextTask,
                    request_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                    response_serializer=control__server__pb2.TaskItem.SerializeToString,
            ),
            'SetTaskStarted': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTaskStarted,
                    request_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int64Value.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            ),
            'SetTaskFinished': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTaskFinished,
                    request_deserializer=control__server__pb2.TaskExecMessage.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            ),
            'SetSlotTerminated': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSlotTerminated,
                    request_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            ),
            'GetRunnableSlotList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRunnableSlotList,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=control__server__pb2.CommandList.SerializeToString,
            ),
            'SetSlotInitialized': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSlotInitialized,
                    request_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            ),
            'GetTerminableSlotList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTerminableSlotList,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=control__server__pb2.CommandList.SerializeToString,
            ),
            'GetRunnableWorkerList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRunnableWorkerList,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=control__server__pb2.CommandList.SerializeToString,
            ),
            'SetWorkerInitialized': grpc.unary_unary_rpc_method_handler(
                    servicer.SetWorkerInitialized,
                    request_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            ),
            'GetTerminableWorkerList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTerminableWorkerList,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=control__server__pb2.CommandList.SerializeToString,
            ),
            'SetWorkerTerminated': grpc.unary_unary_rpc_method_handler(
                    servicer.SetWorkerTerminated,
                    request_deserializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            ),
            'SendToNextJob': grpc.unary_unary_rpc_method_handler(
                    servicer.SendToNextJob,
                    request_deserializer=control__server__pb2.JobKey.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            ),
            'SendMessagesToNext': grpc.unary_unary_rpc_method_handler(
                    servicer.SendMessagesToNext,
                    request_deserializer=control__server__pb2.JobKeys.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalebox.BoxService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BoxService(object):
    """service ControlService {
    """

    @staticmethod
    def Echo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/Echo',
            google_dot_protobuf_dot_wrappers__pb2.StringValue.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.StringValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNextTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/GetNextTask',
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            control__server__pb2.TaskItem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTaskStarted(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/SetTaskStarted',
            google_dot_protobuf_dot_wrappers__pb2.Int64Value.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTaskFinished(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/SetTaskFinished',
            control__server__pb2.TaskExecMessage.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSlotTerminated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/SetSlotTerminated',
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRunnableSlotList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/GetRunnableSlotList',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            control__server__pb2.CommandList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSlotInitialized(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/SetSlotInitialized',
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTerminableSlotList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/GetTerminableSlotList',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            control__server__pb2.CommandList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRunnableWorkerList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/GetRunnableWorkerList',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            control__server__pb2.CommandList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetWorkerInitialized(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/SetWorkerInitialized',
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTerminableWorkerList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/GetTerminableWorkerList',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            control__server__pb2.CommandList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetWorkerTerminated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/SetWorkerTerminated',
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendToNextJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/SendToNextJob',
            control__server__pb2.JobKey.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendMessagesToNext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalebox.BoxService/SendMessagesToNext',
            control__server__pb2.JobKeys.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.Int32Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
